@@ -1636,6 +1636,45 @@ END
 
 };
 
+our $gnusocial_create_access_token=sub {
+
+   package gnusocial_create_access_token;
+   my $create_access_token_banner=<<'END';
+
+    ___              _           _                     _____    _
+   / __|_ _ ___ __ _| |_ ___    /_\  __ __ ___ ______ |_   _|__| |_____ _ _
+  | (__| '_/ -_) _` |  _/ -_)  / _ \/ _/ _/ -_|_-<_-<   | |/ _ \ / / -_) ' \
+   \___|_| \___\__,_|\__\___| /_/ \_\__\__\___/__/__/   |_|\___/_\_\___|_||_|
+
+END
+   $create_access_token_banner.=<<END;
+                      ________________________
+                     |                        |                
+   Details  Settings | Keys and Access Tokens | Permissions  
+  ___________________|                        |________________________________
+
+   On the same 'Keys and Access Tokens' Tab/Page, there is a button
+   at the bottom of the page named 'Create my access token'.
+
+   Click the 'Create my access token' button at bottom of page.
+
+    ________________________
+   | Create my access token |
+   |________________________|
+
+END
+   my $gnusocial_access_token={
+
+      Name => 'gnusocial_access_token',
+      Result =>
+   $Net::FullAuto::ISets::Amazon::GNUSocial_is::gnusocial_twitter_permissions,
+      Banner => $create_access_token_banner,
+
+   };
+   return $gnusocial_access_token;
+
+};
+
 our $gnusocial_twitter_permissions=sub {
 
    my $twitter_permission_banner=<<'END';
@@ -1704,7 +1743,7 @@ END
       Name => 'gnusocial_twitter_api',
       Input => 1,
       Result =>
-   $Net::FullAuto::ISets::Amazon::GNUSocial_is::gnusocial_twitter_permissions,
+   $Net::FullAuto::ISets::Amazon::GNUSocial_is::gnusocial_create_access_token,
       Banner => $twitter_api_banner,
 
    };
